==> qmmp-1.1.9-1-src.tar.xz: qmmp-1.1.9/src/plugins/Input/gme/translations/gme_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="50"/>
        <source>GME Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="53"/>
        <source>Game Music Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="117"/>
        <source>About GME Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="118"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="119"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="120"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-1.1.12-2-src.tar.xz: qmmp-1.1.12/src/plugins/Input/gme/translations/gme_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="50"/>
        <source>GME Plugin</source>
        <translation>Módulo GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="53"/>
        <source>Game Music Files</source>
        <translation>Archivos de Game Music</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="117"/>
        <source>About GME Audio Plugin</source>
        <translation>Acerca del Módulo de Audio GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="118"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Módulo de Audio GME de Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="119"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Este módulo usa la biblioteca Game_Music_Emu para reproducir archivos de música</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="120"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>Configuración de Módulo GME</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>Longitud de fundido:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>Habilitar salida con fundido</translation>
    </message>
</context>
</TS>
